@@ -24,11 +24,13 @@
 from datetime import datetime, timezone
 
 from thetaetl.service.graph_operations import GraphOperations, OutOfBoundsError, Point
-
+from thetaetl.json_rpc_requests import generate_get_blocks_by_range_json_rpc
+from thetaetl.utils import rpc_response_to_result
+from thetaetl.mappers.block_mapper import ThetaBlockMapper
 
 class ThetaService(object):
-    def __init__(self, web3):
-        graph = BlockTimestampGraph(web3)
+    def __init__(self, theta_provider):
+        graph = BlockTimestampGraph(theta_provider)
         self._graph_operations = GraphOperations(graph)
 
     def get_block_range_for_date(self, date):
@@ -66,19 +68,27 @@ class ThetaService(object):
 
 
 class BlockTimestampGraph(object):
-    def __init__(self, web3):
-        self._web3 = web3
+    def __init__(self, theta_provider):
+        self._theta_provider= theta_provider
+        self.block_mapper = ThetaBlockMapper()
 
     def get_first_point(self):
         # Ignore the genesis block as its timestamp is 0
-        return block_to_point(self._web3.eth.getBlock(1))
+        # response = self._theta_provider.make_request(
+        #     json.dumps(generate_get_blocks_by_range_json_rpc(1, 1, False))
+        #     )
+        response = self._theta_provider.make_request(generate_get_blocks_by_range_json_rpc(1, 1, False))
+        results = rpc_response_to_result(response)
+        blocks = [self.block_mapper.json_dict_to_block(result) for result in results]
+
+        return block_to_point(blocks[0]) #TODO: make text
 
     def get_last_point(self):
-        return block_to_point(self._web3.eth.getBlock('latest'))
+        return block_to_point(self._theta_provider.eth.getBlock('latest'))
 
     def get_point(self, x):
-        return block_to_point(self._web3.eth.getBlock(x))
+        return block_to_point(self._theta_provider.eth.getBlock(x))
 
 
 def block_to_point(block):
-    return Point(block.number, block.timestamp)
+    return Point(block.height, block.timestamp)
